.. PySubsonic documentation master file, created by
   sphinx-quickstart on Sat Nov 12 13:51:38 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PySubsonic's documentation!
======================================
`AutoAPI <autoapi/index.html>`_